@@ -2,6 +2,8 @@
 """
 import copy
 
+from django.core.exceptions import ObjectDoesNotExist
+
 from core_dashboard_common_app import constants as dashboard_constants
 from core_dashboard_common_app import settings
 from core_dashboard_common_app.views.common.forms import UserForm
@@ -32,10 +34,13 @@ class DashboardWorkspaceTabs(CommonView):
         items_to_render = []
 
         context = {}
-
+        data_count = 0
+        files_count = 0
         try:
             data = workspace_data_api.get_all_by_workspace(workspace, request.user)
+            data_count = data.count()
             files = workspace_blob_api.get_all_by_workspace(workspace, request.user)
+            files_count = files.count()
 
             if tab_selected == "data":
                 items_to_render = data
@@ -50,7 +55,7 @@ class DashboardWorkspaceTabs(CommonView):
                     {"document": dashboard_constants.FUNCTIONAL_OBJECT_ENUM.FILE.value}
                 )
         except AccessControlError as ace:
-            items_to_render = []
+            items_to_render = workspace_data_api.get_none()
 
         user_can_read = workspace_api.can_user_read_workspace(workspace, request.user)
         user_can_write = workspace_api.can_user_write_workspace(workspace, request.user)
@@ -85,8 +90,8 @@ class DashboardWorkspaceTabs(CommonView):
                 ),
                 "tab": tab_selected,
                 "title": workspace.title,
-                "number_total_data": data.count(),
-                "number_total_files": files.count(),
+                "number_total_data": data_count,
+                "number_total_files": files_count,
             }
         )
 
@@ -131,11 +136,15 @@ class DashboardWorkspaceTabs(CommonView):
             if tab_selected == "data":
                 document_context.update({"data": document, "is_owner": is_owner})
             elif tab_selected == "file":
+                try:
+                    username = user_api.get_user_by_id(document.user_id).username
+                except ObjectDoesNotExist:
+                    username = "None"
                 document_context.update(
                     {
                         "file": document,
                         "url": blob_utils.get_blob_download_uri(document, request),
-                        "user": user_api.get_user_by_id(document.user_id).username,
+                        "user": username,
                         "date": document.id.generation_time,
                         "is_owner": is_owner,
                     }
